"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub,
    ctx,
    job_id: str,
    client_token: str,
    current_revision: Dict = None,
    continuation_token: str = None,
    execution_details: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Represents the success of a third party job as returned to the pipeline by a job worker. Used for partner actions only.

    Args:
        job_id(str): The ID of the job that successfully completed. This is the same ID returned from PollForThirdPartyJobs.
        client_token(str): The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.
        current_revision(Dict, optional): Represents information about a current revision. Defaults to None.
        continuation_token(str, optional): A token generated by a job worker, such as an AWS CodeDeploy deployment ID, that a successful job provides to identify a partner action in progress. Future jobs use this token to identify the running instance of the action. It can be reused to return more information about the progress of the partner action. When the action is complete, no continuation token should be supplied. Defaults to None.
        execution_details(Dict, optional): The details of the actions taken and results produced on an artifact as it passes through stages in the pipeline. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.third_party_job.success_result.put(
                ctx, job_id=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.third_party_job.success_result.put job_id=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="put_third_party_job_success_result",
        op_kwargs={
            "jobId": job_id,
            "clientToken": client_token,
            "currentRevision": current_revision,
            "continuationToken": continuation_token,
            "executionDetails": execution_details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, api_id: str, format_: str, include_directives: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the introspection schema for a GraphQL API.

    Args:
        api_id(str): The API ID.
        format_(str): The schema format: SDL or JSON.
        include_directives(bool, optional): A flag that specifies whether the schema introspection should contain directives. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.introspection_schema.get(
                ctx, api_id=value, format_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.introspection_schema.get api_id=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="get_introspection_schema",
        op_kwargs={
            "apiId": api_id,
            "format": format_,
            "includeDirectives": include_directives,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, function_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes a concurrent execution limit from a function.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.concurrency.delete(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.concurrency.delete function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_function_concurrency",
        op_kwargs={"FunctionName": function_name},
    )


async def get(hub, ctx, function_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns details about the reserved concurrency configuration for a function. To set a concurrency limit for a function, use PutFunctionConcurrency.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.concurrency.get(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.concurrency.get function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_function_concurrency",
        op_kwargs={"FunctionName": function_name},
    )


async def put(
    hub, ctx, function_name: str, reserved_concurrent_executions: int
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level. Concurrency settings apply to the function as a whole, including all published versions and the unpublished version. Reserving concurrency both ensures that your function has capacity to process the specified number of events simultaneously, and prevents it from scaling beyond that level. Use GetFunction to see the current setting for a function. Use GetAccountSettings to see your Regional concurrency limit. You can reserve concurrency for as many functions as you like, as long as you leave at least 100 simultaneous executions unreserved for functions that aren't configured with a per-function limit. For more information, see Managing Concurrency.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        reserved_concurrent_executions(int): The number of simultaneous executions to reserve for the function.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.concurrency.put(
                ctx, function_name=value, reserved_concurrent_executions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.concurrency.put function_name=value, reserved_concurrent_executions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="put_function_concurrency",
        op_kwargs={
            "FunctionName": function_name,
            "ReservedConcurrentExecutions": reserved_concurrent_executions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disables an Amazon Macie account and deletes Macie resources for the account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.macie.init.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.macie.init.disable
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="macie2", operation="disable_macie", op_kwargs={}
    )


async def enable(
    hub,
    ctx,
    client_token: str = None,
    finding_publishing_frequency: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables Amazon Macie and specifies the configuration settings for a Macie account.

    Args:
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.
        finding_publishing_frequency(str, optional): Specifies how often to publish updates to policy findings for the account. This includes publishing updates to Security Hub and Amazon EventBridge (formerly called Amazon CloudWatch Events). Defaults to None.
        status(str, optional): Specifies the new status for the account. To enable Amazon Macie and start all Macie activities for the account, set this value to ENABLED. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.macie.init.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.macie.init.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="enable_macie",
        op_kwargs={
            "clientToken": client_token,
            "findingPublishingFrequency": finding_publishing_frequency,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a job. Used for custom actions only.  When this API is called, AWS CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts. This API also returns any secret values defined for the action.

    Args:
        job_id(str): The unique system-generated ID for the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.job.detail.get_all(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.job.detail.get_all job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="get_job_details",
        op_kwargs={"jobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

     Associate a set of tags with a Timestream resource. You can then activate these user-defined tags so that they appear on the Billing and Cost Management console for cost allocation tracking.

    Args:
        resource_arn(str):  Identifies the Timestream resource to which tags should be added. This value is an Amazon Resource Name (ARN). .
        tags(List):  The tags to be assigned to the Timestream resource. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

     Removes the association of tags from a Timestream resource.

    Args:
        resource_arn(str):  The Timestream resource that the tags will be removed from. This value is an Amazon Resource Name (ARN). .
        tag_keys(List):  A list of tags keys. Existing tags of the resource whose keys are members of this list will be removed from the Timestream resource. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Add a tag to a Step Functions resource. An array of key-value pairs. For more information, see Using Cost Allocation Tags in the AWS Billing and Cost Management User Guide, and Controlling Access Using IAM Tags. Tags may only contain Unicode letters, digits, white space, or these symbols: _ . : / = + - @.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the Step Functions state machine or activity.
        tags(List): The list of tags to add to a resource. Tags may only contain Unicode letters, digits, white space, or these symbols: _ . : / = + - @.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove a tag from a Step Functions resource

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the Step Functions state machine or activity.
        tag_keys(List): The list of tags to remove from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    dataset_name: str = None,
    max_results: int = None,
    next_token: str = None,
    project_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the DataBrew jobs that are defined.

    Args:
        dataset_name(str, optional): The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified dataset. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.
        next_token(str, optional): A token generated by DataBrew that specifies where to continue pagination if a previous request was truncated. To get the next set of pages, pass in the NextToken value from the response object of the previous page call. . Defaults to None.
        project_name(str, optional): The name of a project. Using this parameter indicates to return only those jobs that are associated with the specified project. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.jobs.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.jobs.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_jobs",
        op_kwargs={
            "DatasetName": dataset_name,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ProjectName": project_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    api_stages: List = None,
    throttle: Dict = None,
    quota: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a usage plan with the throttle and quota limits, as well as the associated API stages, specified in the payload.

    Args:
        name(str): [Required] The name of the usage plan.
        description(str, optional): The description of the usage plan. Defaults to None.
        api_stages(List, optional): The associated API stages of the usage plan. Defaults to None.
        throttle(Dict, optional): The throttling limits of the usage plan. Defaults to None.
        quota(Dict, optional): The quota of the usage plan. Defaults to None.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_usage_plan",
        op_kwargs={
            "name": name,
            "description": description,
            "apiStages": api_stages,
            "throttle": throttle,
            "quota": quota,
            "tags": tags,
        },
    )


async def delete(hub, ctx, usage_plan_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a usage plan of a given plan Id.

    Args:
        usage_plan_id(str): [Required] The Id of the to-be-deleted usage plan.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.init.delete(ctx, usage_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.init.delete usage_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_usage_plan",
        op_kwargs={"usagePlanId": usage_plan_id},
    )


async def get(hub, ctx, usage_plan_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a usage plan of a given plan identifier.

    Args:
        usage_plan_id(str): [Required] The identifier of the UsagePlan resource to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.init.get(ctx, usage_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.init.get usage_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_usage_plan",
        op_kwargs={"usagePlanId": usage_plan_id},
    )


async def get_all(
    hub, ctx, position: str = None, key_id: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all the usage plans of the caller's account.

    Args:
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        key_id(str, optional): The identifier of the API key associated with the usage plans. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_usage_plans",
        op_kwargs={"position": position, "keyId": key_id, "limit": limit},
    )


async def update(hub, ctx, usage_plan_id: str, patch_operations: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a usage plan of a given plan Id.

    Args:
        usage_plan_id(str): [Required] The Id of the to-be-updated usage plan.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.init.update(ctx, usage_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.init.update usage_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_usage_plan",
        op_kwargs={"usagePlanId": usage_plan_id, "patchOperations": patch_operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of powers that can be specified for your Amazon Lightsail container services. The power specifies the amount of memory, the number of vCPUs, and the base price of the container service.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.power.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.power.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_container_service_powers",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, instance_arn: str, resource_arn: str, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags that are attached to a specified resource.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        resource_arn(str): The ARN of the resource with the tags to be listed.
        next_token(str, optional): The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.tags_for_resource.list(
                ctx, instance_arn=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.tags_for_resource.list instance_arn=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="list_tags_for_resource",
        op_kwargs={
            "InstanceArn": instance_arn,
            "ResourceArn": resource_arn,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(
    hub,
    ctx,
    user_pool_id: str,
    username: str,
    limit: int = None,
    pagination_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists devices, as an administrator. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID.
        username(str): The user name.
        limit(int, optional): The limit of the devices request. Defaults to None.
        pagination_token(str, optional): The pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.list_.device.admin(
                ctx, user_pool_id=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.list_.device.admin user_pool_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_list_devices",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "Limit": limit,
            "PaginationToken": pagination_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, account_id: str, room_id: str, member_id: str, role: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a member to a chat room in an Amazon Chime Enterprise account. A member can be either a user or a bot. The member role designates whether the member is a chat room administrator or a general chat room member.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.
        member_id(str): The Amazon Chime member ID (user ID or bot ID).
        role(str, optional): The role of the member. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.membership.create(
                ctx, account_id=value, room_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.membership.create account_id=value, room_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_room_membership",
        op_kwargs={
            "AccountId": account_id,
            "RoomId": room_id,
            "MemberId": member_id,
            "Role": role,
        },
    )


async def delete(hub, ctx, account_id: str, room_id: str, member_id: str) -> None:
    r"""
    **Autogenerated function**

    Removes a member from a chat room in an Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.
        member_id(str): The member ID (user ID or bot ID).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.membership.delete(
                ctx, account_id=value, room_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.membership.delete account_id=value, room_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_room_membership",
        op_kwargs={"AccountId": account_id, "RoomId": room_id, "MemberId": member_id},
    )


async def list_all(
    hub,
    ctx,
    account_id: str,
    room_id: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the membership details for the specified room in an Amazon Chime Enterprise account, such as the members' IDs, email addresses, and names.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.membership.list_all(
                ctx, account_id=value, room_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.membership.list_all account_id=value, room_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_room_memberships",
        op_kwargs={
            "AccountId": account_id,
            "RoomId": room_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, account_id: str, room_id: str, member_id: str, role: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates room membership details, such as the member role, for a room in an Amazon Chime Enterprise account. The member role designates whether the member is a chat room administrator or a general chat room member. The member role can be updated only for user IDs.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.
        member_id(str): The member ID.
        role(str, optional): The role of the member. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.room.membership.update(
                ctx, account_id=value, room_id=value, member_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.room.membership.update account_id=value, room_id=value, member_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_room_membership",
        op_kwargs={
            "AccountId": account_id,
            "RoomId": room_id,
            "MemberId": member_id,
            "Role": role,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_token: str = None,
    description: str = None,
    ignore_words: List = None,
    keywords: List = None,
    maximum_match_distance: int = None,
    name: str = None,
    regex: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates and defines the criteria and other settings for a custom data identifier.

    Args:
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.
        description(str, optional): A custom description of the custom data identifier. The description can contain as many as 512 characters. We strongly recommend that you avoid including any sensitive data in the description of a custom data identifier. Other users of your account might be able to see the identifier's description, depending on the actions that they're allowed to perform in Amazon Macie. Defaults to None.
        ignore_words(List, optional): An array that lists specific character sequences (ignore words) to exclude from the results. If the text matched by the regular expression is the same as any string in this array, Amazon Macie ignores it. The array can contain as many as 10 ignore words. Each ignore word can contain 4-90 characters. Ignore words are case sensitive. Defaults to None.
        keywords(List, optional): An array that lists specific character sequences (keywords), one of which must be within proximity (maximumMatchDistance) of the regular expression to match. The array can contain as many as 50 keywords. Each keyword can contain 3-90 characters. Keywords aren't case sensitive. Defaults to None.
        maximum_match_distance(int, optional): The maximum number of characters that can exist between text that matches the regex pattern and the character sequences specified by the keywords array. Macie includes or excludes a result based on the proximity of a keyword to text that matches the regex pattern. The distance can be 1-300 characters. The default value is 50. Defaults to None.
        name(str, optional): A custom name for the custom data identifier. The name can contain as many as 128 characters. We strongly recommend that you avoid including any sensitive data in the name of a custom data identifier. Other users of your account might be able to see the identifier's name, depending on the actions that they're allowed to perform in Amazon Macie. Defaults to None.
        regex(str, optional): The regular expression (regex) that defines the pattern to match. The expression can contain as many as 512 characters. Defaults to None.
        tags(Dict, optional): A map of key-value pairs that specifies the tags to associate with the custom data identifier. A custom data identifier can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.custom_data_identifier.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.custom_data_identifier.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="create_custom_data_identifier",
        op_kwargs={
            "clientToken": client_token,
            "description": description,
            "ignoreWords": ignore_words,
            "keywords": keywords,
            "maximumMatchDistance": maximum_match_distance,
            "name": name,
            "regex": regex,
            "tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Soft deletes a custom data identifier.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.custom_data_identifier.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.custom_data_identifier.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="delete_custom_data_identifier",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the criteria and other settings for a custom data identifier.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.custom_data_identifier.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.custom_data_identifier.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_custom_data_identifier",
        op_kwargs={"id": id_},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a subset of information about all the custom data identifiers for an account.

    Args:
        max_results(int, optional): The maximum number of items to include in each page of the response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.custom_data_identifier.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.custom_data_identifier.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_custom_data_identifiers",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def test(
    hub,
    ctx,
    regex: str,
    sample_text: str,
    ignore_words: List = None,
    keywords: List = None,
    maximum_match_distance: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Tests a custom data identifier.

    Args:
        ignore_words(List, optional): An array that lists specific character sequences (ignore words) to exclude from the results. If the text matched by the regular expression is the same as any string in this array, Amazon Macie ignores it. The array can contain as many as 10 ignore words. Each ignore word can contain 4-90 characters. Ignore words are case sensitive. Defaults to None.
        keywords(List, optional): An array that lists specific character sequences (keywords), one of which must be within proximity (maximumMatchDistance) of the regular expression to match. The array can contain as many as 50 keywords. Each keyword can contain 3-90 characters. Keywords aren't case sensitive. Defaults to None.
        maximum_match_distance(int, optional): The maximum number of characters that can exist between text that matches the regex pattern and the character sequences specified by the keywords array. Macie includes or excludes a result based on the proximity of a keyword to text that matches the regex pattern. The distance can be 1-300 characters. The default value is 50. Defaults to None.
        regex(str): The regular expression (regex) that defines the pattern to match. The expression can contain as many as 512 characters.
        sample_text(str): The sample text to inspect by using the custom data identifier. The text can contain as many as 1,000 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.custom_data_identifier.test(
                ctx, regex=value, sample_text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.custom_data_identifier.test regex=value, sample_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="test_custom_data_identifier",
        op_kwargs={
            "ignoreWords": ignore_words,
            "keywords": keywords,
            "maximumMatchDistance": maximum_match_distance,
            "regex": regex,
            "sampleText": sample_text,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, key_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes key material that you previously imported. This operation makes the specified customer master key (CMK) unusable. For more information about importing key material into AWS KMS, see Importing Key Material in the AWS Key Management Service Developer Guide.  When the specified CMK is in the PendingDeletion state, this operation does not change the CMK's state. Otherwise, it changes the CMK's state to PendingImport. After you delete key material, you can use ImportKeyMaterial to reimport the same key material into the CMK. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:DeleteImportedKeyMaterial (key policy)  Related operations:     GetParametersForImport     ImportKeyMaterial

    Args:
        key_id(str): Identifies the CMK from which you are deleting imported key material. The Origin of the CMK must be EXTERNAL. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.imported_key_material.delete(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.imported_key_material.delete key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="delete_imported_key_material",
        op_kwargs={"KeyId": key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, policy_id: str, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the resource policy that AWS Resource Access Manager uses to share your Incident Manager resource.

    Args:
        policy_id(str): The ID of the resource policy you're deleting.
        resource_arn(str): The Amazon Resource Name (ARN) of the resource you're deleting the policy from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.resource.policy.delete(
                ctx, policy_id=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.resource.policy.delete policy_id=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="delete_resource_policy",
        op_kwargs={"policyId": policy_id, "resourceArn": resource_arn},
    )


async def get_all(
    hub, ctx, resource_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the resource policies attached to the specified response plan.

    Args:
        max_results(int, optional): The maximum number of resource policies to display per page of results. Defaults to None.
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the response plan with the attached resource policy. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.resource.policy.get_all(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.resource.policy.get_all resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="get_resource_policies",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "resourceArn": resource_arn,
        },
    )


async def put(hub, ctx, policy: str, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds a resource policy to the specified response plan.

    Args:
        policy(str): Details of the resource policy.
        resource_arn(str): The Amazon Resource Name (ARN) of the response plan you're adding the resource policy to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.resource.policy.put(
                ctx, policy=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.resource.policy.put policy=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="put_resource_policy",
        op_kwargs={"policy": policy, "resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    repository_association_arn: str,
    type_: Dict,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Use to create a code review with a  CodeReviewType  of RepositoryAnalysis. This type of code review analyzes all code under a specified branch in an associated repository. PullRequest code reviews are automatically triggered by a pull request.

    Args:
        name(str):  The name of the code review. The name of each code review in your AWS account must be unique. .
        repository_association_arn(str):  The Amazon Resource Name (ARN) of the  RepositoryAssociation  object. You can retrieve this ARN by calling  ListRepositoryAssociations .   A code review can only be created on an associated repository. This is the ARN of the associated repository. .
        type_(Dict):  The type of code review to create. This is specified using a  CodeReviewType  object. You can create a code review only of type RepositoryAnalysis. .
        client_request_token(str, optional):  Amazon CodeGuru Reviewer uses this value to prevent the accidental creation of duplicate code reviews if there are failures and retries. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.code_review.create(
                ctx, name=value, repository_association_arn=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.code_review.create name=value, repository_association_arn=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="create_code_review",
        op_kwargs={
            "Name": name,
            "RepositoryAssociationArn": repository_association_arn,
            "Type": type_,
            "ClientRequestToken": client_request_token,
        },
    )


async def describe(hub, ctx, code_review_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns the metadata associated with the code review along with its status.

    Args:
        code_review_arn(str): The Amazon Resource Name (ARN) of the  CodeReview  object. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.code_review.describe(
                ctx, code_review_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.code_review.describe code_review_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="describe_code_review",
        op_kwargs={"CodeReviewArn": code_review_arn},
    )


async def list_all(
    hub,
    ctx,
    type_: str,
    provider_types: List = None,
    states: List = None,
    repository_names: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists all the code reviews that the customer has created in the past 90 days.

    Args:
        provider_types(List, optional):  List of provider types for filtering that needs to be applied before displaying the result. For example, providerTypes=[GitHub] lists code reviews from GitHub. . Defaults to None.
        states(List, optional):  List of states for filtering that needs to be applied before displaying the result. For example, states=[Pending] lists code reviews in the Pending state.  The valid code review states are:    Completed: The code review is complete.     Pending: The code review started and has not completed or failed.     Failed: The code review failed.     Deleting: The code review is being deleted.   . Defaults to None.
        repository_names(List, optional):  List of repository names for filtering that needs to be applied before displaying the result. . Defaults to None.
        type_(str):  The type of code reviews to list in the response. .
        max_results(int, optional):  The maximum number of results that are returned per call. The default is 100. . Defaults to None.
        next_token(str, optional):  If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.code_review.list_all(ctx, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.code_review.list_all type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="list_code_reviews",
        op_kwargs={
            "ProviderTypes": provider_types,
            "States": states,
            "RepositoryNames": repository_names,
            "Type": type_,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, log_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified retention policy. Log events do not expire if they belong to log groups without a retention policy.

    Args:
        log_group_name(str): The name of the log group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.retention_policy.delete(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.retention_policy.delete log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_retention_policy",
        op_kwargs={"logGroupName": log_group_name},
    )


async def put(hub, ctx, log_group_name: str, retention_in_days: int) -> None:
    r"""
    **Autogenerated function**

    Sets the retention of the specified log group. A retention policy allows you to configure the number of days for which to retain log events in the specified log group.

    Args:
        log_group_name(str): The name of the log group.
        retention_in_days(int): The number of days to retain the log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, and 3653. If you omit retentionInDays in a PutRetentionPolicy operation, the events in the log group are always retained and never expire.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.retention_policy.put(
                ctx, log_group_name=value, retention_in_days=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.retention_policy.put log_group_name=value, retention_in_days=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_retention_policy",
        op_kwargs={
            "logGroupName": log_group_name,
            "retentionInDays": retention_in_days,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags for an Amazon Forecast resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the supported resources are Forecast dataset groups, datasets, dataset import jobs, predictors, forecasts, and forecast export jobs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, progress_update_stream_name: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a progress update stream which is an AWS resource used for access control as well as a namespace for migration task names that is implicitly linked to your AWS account. It must uniquely identify the migration tool as it is used for all updates made by the tool; however, it does not need to be unique for each AWS account because it is scoped to the AWS account.

    Args:
        progress_update_stream_name(str): The name of the ProgressUpdateStream. Do not store personal data in this field. .
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.progress_update_stream.create(
                ctx, progress_update_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.progress_update_stream.create progress_update_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="create_progress_update_stream",
        op_kwargs={
            "ProgressUpdateStreamName": progress_update_stream_name,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, progress_update_stream_name: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a progress update stream, including all of its tasks, which was previously created as an AWS resource used for access control. This API has the following traits:   The only parameter needed for DeleteProgressUpdateStream is the stream name (same as a CreateProgressUpdateStream call).   The call will return, and a background process will asynchronously delete the stream and all of its resources (tasks, associated resources, resource attributes, created artifacts).   If the stream takes time to be deleted, it might still show up on a ListProgressUpdateStreams call.    CreateProgressUpdateStream, ImportMigrationTask, NotifyMigrationTaskState, and all Associate[*] APIs related to the tasks belonging to the stream will throw "InvalidInputException" if the stream of the same name is in the process of being deleted.   Once the stream and all of its resources are deleted, CreateProgressUpdateStream for a stream of the same name will succeed, and that stream will be an entirely new logical resource (without any resources associated with the old stream).

    Args:
        progress_update_stream_name(str): The name of the ProgressUpdateStream. Do not store personal data in this field. .
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.progress_update_stream.delete(
                ctx, progress_update_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.progress_update_stream.delete progress_update_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="delete_progress_update_stream",
        op_kwargs={
            "ProgressUpdateStreamName": progress_update_stream_name,
            "DryRun": dry_run,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists progress update streams associated with the user account making this call.

    Args:
        next_token(str, optional): If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken. Defaults to None.
        max_results(int, optional): Filter to limit the maximum number of results to list per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.progress_update_stream.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.progress_update_stream.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="list_progress_update_streams",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, ip: str) -> Dict:
    r"""
    **Autogenerated function**

    Get information about a dedicated IP address, including the name of the dedicated IP pool that it's associated with, as well information about the automatic warm-up process for the address.

    Args:
        ip(str): The IP address that you want to obtain more information about. The value you specify has to be a dedicated IP address that's assocaited with your AWS account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.init.get(ctx, ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.init.get ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sesv2", operation="get_dedicated_ip", op_kwargs={"Ip": ip}
    )


async def get_all(
    hub, ctx, pool_name: str = None, next_token: str = None, page_size: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the dedicated IP addresses that are associated with your AWS account.

    Args:
        pool_name(str, optional): The name of the IP pool that the dedicated IP address is associated with. Defaults to None.
        next_token(str, optional): A token returned from a previous call to GetDedicatedIps to indicate the position of the dedicated IP pool in the list of IP pools. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to GetDedicatedIpsRequest. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_dedicated_ips",
        op_kwargs={
            "PoolName": pool_name,
            "NextToken": next_token,
            "PageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to a signaling channel. A tag is a key-value pair (the value is optional) that you can define and assign to AWS resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see Using Cost Allocation Tags in the AWS Billing and Cost Management User Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the signaling channel to which you want to add tags.
        tags(List): A list of tags to associate with the specified signaling channel. Each tag is a key-value pair.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_key_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from a signaling channel. In the request, specify only a tag key or keys; don't specify the value. If you specify a tag key that does not exist, it's ignored.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the signaling channel from which you want to remove tags.
        tag_key_list(List): A list of the keys of the tags that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.resource.untag(
                ctx, resource_arn=value, tag_key_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.resource.untag resource_arn=value, tag_key_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeyList": tag_key_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "filter"


async def create(
    hub,
    ctx,
    action: str,
    finding_criteria: Dict,
    name: str,
    client_token: str = None,
    description: str = None,
    position: int = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates and defines the criteria and other settings for a findings filter.

    Args:
        action(str): The action to perform on findings that meet the filter criteria (findingCriteria). Valid values are: ARCHIVE, suppress (automatically archive) the findings; and, NOOP, don't perform any action on the findings.
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.
        description(str, optional): A custom description of the filter. The description can contain as many as 512 characters. We strongly recommend that you avoid including any sensitive data in the description of a filter. Other users of your account might be able to see the filter's description, depending on the actions that they're allowed to perform in Amazon Macie. Defaults to None.
        finding_criteria(Dict): The criteria to use to filter findings.
        name(str): A custom name for the filter. The name must contain at least 3 characters and can contain as many as 64 characters. We strongly recommend that you avoid including any sensitive data in the name of a filter. Other users of your account might be able to see the filter's name, depending on the actions that they're allowed to perform in Amazon Macie.
        position(int, optional): The position of the filter in the list of saved filters on the Amazon Macie console. This value also determines the order in which the filter is applied to findings, relative to other filters that are also applied to the findings. Defaults to None.
        tags(Dict, optional): A map of key-value pairs that specifies the tags to associate with the filter. A findings filter can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.filter_.create(
                ctx, action=value, finding_criteria=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.filter.create action=value, finding_criteria=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="create_findings_filter",
        op_kwargs={
            "action": action,
            "clientToken": client_token,
            "description": description,
            "findingCriteria": finding_criteria,
            "name": name,
            "position": position,
            "tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a findings filter.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.filter_.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.filter.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="delete_findings_filter",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the criteria and other settings for a findings filter.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.filter_.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.filter.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_findings_filter",
        op_kwargs={"id": id_},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a subset of information about all the findings filters for an account.

    Args:
        max_results(int, optional): The maximum number of items to include in each page of a paginated response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.filter_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.filter.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_findings_filters",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    id_: str,
    action: str = None,
    description: str = None,
    finding_criteria: Dict = None,
    name: str = None,
    position: int = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the criteria and other settings for a findings filter.

    Args:
        action(str, optional): The action to perform on findings that meet the filter criteria (findingCriteria). Valid values are: ARCHIVE, suppress (automatically archive) the findings; and, NOOP, don't perform any action on the findings. Defaults to None.
        description(str, optional): A custom description of the filter. The description can contain as many as 512 characters. We strongly recommend that you avoid including any sensitive data in the description of a filter. Other users might be able to see the filter's description, depending on the actions that they're allowed to perform in Amazon Macie. Defaults to None.
        finding_criteria(Dict, optional): The criteria to use to filter findings. Defaults to None.
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.
        name(str, optional): A custom name for the filter. The name must contain at least 3 characters and can contain as many as 64 characters. We strongly recommend that you avoid including any sensitive data in the name of a filter. Other users might be able to see the filter's name, depending on the actions that they're allowed to perform in Amazon Macie. Defaults to None.
        position(int, optional): The position of the filter in the list of saved filters on the Amazon Macie console. This value also determines the order in which the filter is applied to findings, relative to other filters that are also applied to the findings. Defaults to None.
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.filter_.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.filter.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="update_findings_filter",
        op_kwargs={
            "action": action,
            "description": description,
            "findingCriteria": finding_criteria,
            "id": id_,
            "name": name,
            "position": position,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, rule_id: str, next_marker: str = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of IP addresses currently being blocked by the RateBasedRule that is specified by the RuleId. The maximum number of managed keys that will be blocked is 10,000. If more than 10,000 addresses exceed the rate limit, the 10,000 addresses with the highest rates will be blocked.

    Args:
        rule_id(str): The RuleId of the RateBasedRule for which you want to get a list of ManagedKeys. RuleId is returned by CreateRateBasedRule and by ListRateBasedRules.
        next_marker(str, optional): A null value and not currently used. Do not include this in your request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rate_based_rule.managed_key.get_all(
                ctx, rule_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rate_based_rule.managed_key.get_all rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_rate_based_rule_managed_keys",
        op_kwargs={"RuleId": rule_id, "NextMarker": next_marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, repository_name: str, layer_digest: str, registry_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the pre-signed Amazon S3 download URL corresponding to an image layer. You can only get URLs for image layers that are referenced in an image. When an image is pulled, the GetDownloadUrlForLayer API is called once per image layer that is not already cached.  This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the docker CLI to pull, tag, and push images.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the image layer to download. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository that is associated with the image layer to download.
        layer_digest(str): The digest of the image layer to download.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.download_url_for_layer.get(
                ctx, repository_name=value, layer_digest=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.download_url_for_layer.get repository_name=value, layer_digest=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="get_download_url_for_layer",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "layerDigest": layer_digest,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    directory_arn: str,
    policy_reference: Dict,
    next_token: str = None,
    max_results: int = None,
    consistency_level: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all of the ObjectIdentifiers to which a given policy is attached.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where objects reside. For more information, see arns.
        policy_reference(Dict): The reference that identifies the policy object.
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum number of items to be retrieved in a single call. This is an approximate number. Defaults to None.
        consistency_level(str, optional): Represents the manner and timing in which the successful write or update of an object is reflected in a subsequent read operation of that same object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.policy.attachment.list_all(
                ctx, directory_arn=value, policy_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.policy.attachment.list_all directory_arn=value, policy_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_policy_attachments",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "PolicyReference": policy_reference,
            "NextToken": next_token,
            "MaxResults": max_results,
            "ConsistencyLevel": consistency_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, profile_name: str) -> None:
    r"""
    **Autogenerated function**

    Changes the state of an ACTIVE signing profile to CANCELED. A canceled profile is still viewable with the ListSigningProfiles operation, but it cannot perform new signing jobs, and is deleted two years after cancelation.

    Args:
        profile_name(str): The name of the signing profile to be canceled.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.profile.cancel(ctx, profile_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.profile.cancel profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="cancel_signing_profile",
        op_kwargs={"profileName": profile_name},
    )


async def get(hub, ctx, profile_name: str, profile_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information on a specific signing profile.

    Args:
        profile_name(str): The name of the target signing profile.
        profile_owner(str, optional): The AWS account ID of the profile owner. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.profile.get(ctx, profile_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.profile.get profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="get_signing_profile",
        op_kwargs={"profileName": profile_name, "profileOwner": profile_owner},
    )


async def list_all(
    hub,
    ctx,
    include_canceled: bool = None,
    max_results: int = None,
    next_token: str = None,
    platform_id: str = None,
    statuses: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all available signing profiles in your AWS account. Returns only profiles with an ACTIVE status unless the includeCanceled request field is set to true. If additional jobs remain to be listed, code signing returns a nextToken value. Use this value in subsequent calls to ListSigningJobs to fetch the remaining values. You can continue calling ListSigningJobs with your maxResults parameter and with new values that code signing returns in the nextToken parameter until all of your signing jobs have been returned.

    Args:
        include_canceled(bool, optional): Designates whether to include profiles with the status of CANCELED. Defaults to None.
        max_results(int, optional): The maximum number of profiles to be returned. Defaults to None.
        next_token(str, optional): Value for specifying the next set of paginated results to return. After you receive a response with truncated results, use this parameter in a subsequent request. Set it to the value of nextToken from the response that you just received. Defaults to None.
        platform_id(str, optional): Filters results to return only signing jobs initiated for a specified signing platform. Defaults to None.
        statuses(List, optional): Filters results to return only signing jobs with statuses in the specified list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.profile.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.profile.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="list_signing_profiles",
        op_kwargs={
            "includeCanceled": include_canceled,
            "maxResults": max_results,
            "nextToken": next_token,
            "platformId": platform_id,
            "statuses": statuses,
        },
    )


async def put(
    hub,
    ctx,
    profile_name: str,
    platform_id: str,
    signing_material: Dict = None,
    signature_validity_period: Dict = None,
    overrides: Dict = None,
    signing_parameters: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a signing profile. A signing profile is a code signing template that can be used to carry out a pre-defined signing job. For more information, see http://docs.aws.amazon.com/signer/latest/developerguide/gs-profile.html

    Args:
        profile_name(str): The name of the signing profile to be created.
        signing_material(Dict, optional): The AWS Certificate Manager certificate that will be used to sign code with the new signing profile. Defaults to None.
        signature_validity_period(Dict, optional): The default validity period override for any signature generated using this signing profile. If unspecified, the default is 135 months. Defaults to None.
        platform_id(str): The ID of the signing platform to be created.
        overrides(Dict, optional): A subfield of platform. This specifies any different configuration options that you want to apply to the chosen platform (such as a different hash-algorithm or signing-algorithm). Defaults to None.
        signing_parameters(Dict, optional): Map of key-value pairs for signing. These can include any information that you want to use during signing. Defaults to None.
        tags(Dict, optional): Tags to be associated with the signing profile that is being created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.profile.put(
                ctx, profile_name=value, platform_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.profile.put profile_name=value, platform_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="put_signing_profile",
        op_kwargs={
            "profileName": profile_name,
            "signingMaterial": signing_material,
            "signatureValidityPeriod": signature_validity_period,
            "platformId": platform_id,
            "overrides": overrides,
            "signingParameters": signing_parameters,
            "tags": tags,
        },
    )


async def revoke(
    hub, ctx, profile_name: str, profile_version: str, reason: str, effective_time: str
) -> None:
    r"""
    **Autogenerated function**

    Changes the state of a signing profile to REVOKED. This indicates that signatures generated using the signing profile after an effective start date are no longer valid.

    Args:
        profile_name(str): The name of the signing profile to be revoked.
        profile_version(str): The version of the signing profile to be revoked.
        reason(str): The reason for revoking a signing profile.
        effective_time(str): A timestamp for when revocation of a Signing Profile should become effective. Signatures generated using the signing profile after this timestamp are not trusted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.profile.revoke(
                ctx, profile_name=value, profile_version=value, reason=value, effective_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.profile.revoke profile_name=value, profile_version=value, reason=value, effective_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="revoke_signing_profile",
        op_kwargs={
            "profileName": profile_name,
            "profileVersion": profile_version,
            "reason": reason,
            "effectiveTime": effective_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    enable: bool,
    client_token: str = None,
    finding_publishing_frequency: str = None,
    data_sources: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a single Amazon GuardDuty detector. A detector is a resource that represents the GuardDuty service. To start using GuardDuty, you must create a detector in each Region where you enable the service. You can have only one detector per account per Region. All data sources are enabled in a new detector by default.

    Args:
        enable(bool): A Boolean value that specifies whether the detector is to be enabled.
        client_token(str, optional): The idempotency token for the create request. Defaults to None.
        finding_publishing_frequency(str, optional): A value that specifies how frequently updated findings are exported. Defaults to None.
        data_sources(Dict, optional): Describes which data sources will be enabled for the detector. Defaults to None.
        tags(Dict, optional): The tags to be added to a new detector resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.detector.create(ctx, enable=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.detector.create enable=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="create_detector",
        op_kwargs={
            "Enable": enable,
            "ClientToken": client_token,
            "FindingPublishingFrequency": finding_publishing_frequency,
            "DataSources": data_sources,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, detector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon GuardDuty detector that is specified by the detector ID.

    Args:
        detector_id(str): The unique ID of the detector that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.detector.delete(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.detector.delete detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="delete_detector",
        op_kwargs={"DetectorId": detector_id},
    )


async def get(hub, ctx, detector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an Amazon GuardDuty detector specified by the detectorId.

    Args:
        detector_id(str): The unique ID of the detector that you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.detector.get(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.detector.get detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_detector",
        op_kwargs={"DetectorId": detector_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists detectorIds of all the existing Amazon GuardDuty detector resources.

    Args:
        max_results(int, optional): You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.detector.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.detector.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_detectors",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    detector_id: str,
    enable: bool = None,
    finding_publishing_frequency: str = None,
    data_sources: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Amazon GuardDuty detector specified by the detectorId.

    Args:
        detector_id(str): The unique ID of the detector to update.
        enable(bool, optional): Specifies whether the detector is enabled or not enabled. Defaults to None.
        finding_publishing_frequency(str, optional): An enum value that specifies how frequently findings are exported, such as to CloudWatch Events. Defaults to None.
        data_sources(Dict, optional): Describes which data sources will be updated. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.detector.update(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.detector.update detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_detector",
        op_kwargs={
            "DetectorId": detector_id,
            "Enable": enable,
            "FindingPublishingFrequency": finding_publishing_frequency,
            "DataSources": data_sources,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of severity levels that you can assign to a support case. The severity level for a case is also a field in the CaseDetails data type that you include for a CreateCase request.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        language(str, optional): The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.severity_level.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.severity_level.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_severity_levels",
        op_kwargs={"language": language},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, application: str, current_revision_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a simulation application with a specific revision id.

    Args:
        application(str): The application information for the simulation application.
        current_revision_id(str, optional): The current revision id for the simulation application. If you provide a value and it matches the latest revision ID, a new version will be created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.application.version.create(
                ctx, application=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.application.version.create application=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_simulation_application_version",
        op_kwargs={
            "application": application,
            "currentRevisionId": current_revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partitions_to_delete: List,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more partitions in a batch operation.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the partition to be deleted resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database in which the table in question resides.
        table_name(str): The name of the table that contains the partitions to be deleted.
        partitions_to_delete(List): A list of PartitionInput structures that define the partitions to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.delete.partition.batch(
                ctx, database_name=value, table_name=value, partitions_to_delete=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.delete.partition.batch database_name=value, table_name=value, partitions_to_delete=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="batch_delete_partition",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionsToDelete": partitions_to_delete,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "principal_id_format"


async def describe(
    hub,
    ctx,
    dry_run: bool = None,
    resources: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference.  By default, all IAM roles and IAM users default to the same ID settings as the root user, unless they explicitly override the settings. This request is useful for identifying those IAM users and IAM roles that have overridden the default ID settings. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        resources(List, optional): The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. . Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.principal_id_format_.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.principal_id_format.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_principal_id_format",
        op_kwargs={
            "DryRun": dry_run,
            "Resources": resources,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, aws_account_id: str, theme_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the read and write permissions for a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme that you're describing.
        theme_id(str): The ID for the theme that you want to describe permissions for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.permission.describe_all(
                ctx, aws_account_id=value, theme_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.permission.describe_all aws_account_id=value, theme_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_theme_permissions",
        op_kwargs={"AwsAccountId": aws_account_id, "ThemeId": theme_id},
    )


async def update_multiple(
    hub,
    ctx,
    aws_account_id: str,
    theme_id: str,
    grant_permissions: List = None,
    revoke_permissions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the resource permissions for a theme. Permissions apply to the action to grant or revoke permissions on, for example "quicksight:DescribeTheme". Theme permissions apply in groupings. Valid groupings include the following for the three levels of permissions, which are user, owner, or no permissions:    User    "quicksight:DescribeTheme"     "quicksight:DescribeThemeAlias"     "quicksight:ListThemeAliases"     "quicksight:ListThemeVersions"      Owner    "quicksight:DescribeTheme"     "quicksight:DescribeThemeAlias"     "quicksight:ListThemeAliases"     "quicksight:ListThemeVersions"     "quicksight:DeleteTheme"     "quicksight:UpdateTheme"     "quicksight:CreateThemeAlias"     "quicksight:DeleteThemeAlias"     "quicksight:UpdateThemeAlias"     "quicksight:UpdateThemePermissions"     "quicksight:DescribeThemePermissions"      To specify no permissions, omit the permissions list.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme.
        theme_id(str): The ID for the theme.
        grant_permissions(List, optional): A list of resource permissions to be granted for the theme. Defaults to None.
        revoke_permissions(List, optional): A list of resource permissions to be revoked from the theme. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.permission.update_multiple(
                ctx, aws_account_id=value, theme_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.permission.update_multiple aws_account_id=value, theme_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_theme_permissions",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "GrantPermissions": grant_permissions,
            "RevokePermissions": revoke_permissions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def execute(
    hub, ctx, transact_statements: List, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     This operation allows you to perform transactional reads or writes on data stored in DynamoDB, using PartiQL.

    Args:
        transact_statements(List):  The list of PartiQL statements representing the transaction to run. .
        client_request_token(str, optional):  Set this value to get remaining results, if NextToken was returned in the statement response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.transaction.execute(ctx, transact_statements=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.transaction.execute transact_statements=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="execute_transaction",
        op_kwargs={
            "TransactStatements": transact_statements,
            "ClientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "import"


async def list_all(hub, ctx, export_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all stacks that are importing an exported output value. To modify or remove an exported output value, first use this action to see which stacks are using it. To see the exported output values in your account, see ListExports.  For more information about importing an exported output value, see the  Fn::ImportValue  function.

    Args:
        export_name(str): The name of the exported output value. CloudFormation returns the stack names that are importing this value. .
        next_token(str, optional): A string (provided by the ListImports response output) that identifies the next page of stacks that are importing the specified exported output value. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.import_.list_all(ctx, export_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.import.list_all export_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_imports",
        op_kwargs={"ExportName": export_name, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    workbook_id: str,
    table_id: str,
    rows_to_upsert: List,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The BatchUpsertTableRows API allows you to upsert one or more rows in a table. The upsert operation takes a filter expression as input and evaluates it to find matching rows on the destination table. If matching rows are found, it will update the cells in the matching rows to new values specified in the request. If no matching rows are found, a new row is added at the end of the table and the cells in that row are set to the new values specified in the request.   You can specify the values to set in some or all of the columns in the table for the matching or newly appended rows. If a column is not explicitly specified for a particular row, then that column will not be updated for that row. To clear out the data in a specific cell, you need to set the value as an empty string ("").

    Args:
        workbook_id(str): The ID of the workbook where the rows are being upserted.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table where the rows are being upserted.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        rows_to_upsert(List):  The list of rows to upsert in the table. Each item in this list needs to have a batch item id to uniquely identify the element in the request, a filter expression to find the rows to update for that element and the cell values to set for each column in the upserted rows. You need to specify at least one item in this list.   Note that if one of the filter formulas in the request fails to evaluate because of an error or one of the column ids in any of the rows does not exist in the table, then the request fails and no updates are made to the table. .
        client_request_token(str, optional):  The request token for performing the update action. Request tokens help to identify duplicate requests. If a call times out or fails due to a transient error like a failed network connection, you can retry the call with the same request token. The service ensures that if the first call using that request token is successfully performed, the second call will not perform the action again.   Note that request tokens are valid only for a few minutes. You cannot use request tokens to dedupe requests spanning hours or days. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.upsert_table_row.batch(
                ctx, workbook_id=value, table_id=value, rows_to_upsert=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.upsert_table_row.batch workbook_id=value, table_id=value, rows_to_upsert=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="batch_upsert_table_rows",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "rowsToUpsert": rows_to_upsert,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, resolver_endpoint_id: str, ip_address: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds IP addresses to an inbound or an outbound Resolver endpoint. If you want to add more than one IP address, submit one AssociateResolverEndpointIpAddress request for each IP address. To remove an IP address from an endpoint, see DisassociateResolverEndpointIpAddress.

    Args:
        resolver_endpoint_id(str): The ID of the Resolver endpoint that you want to associate IP addresses with.
        ip_address(Dict): Either the IPv4 address that you want to add to a Resolver endpoint or a subnet ID. If you specify a subnet ID, Resolver chooses an IP address for you from the available IPs in the specified subnet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.ip_address.associate(
                ctx, resolver_endpoint_id=value, ip_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.ip_address.associate resolver_endpoint_id=value, ip_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="associate_resolver_endpoint_ip_address",
        op_kwargs={"ResolverEndpointId": resolver_endpoint_id, "IpAddress": ip_address},
    )


async def disassociate(hub, ctx, resolver_endpoint_id: str, ip_address: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Removes IP addresses from an inbound or an outbound Resolver endpoint. If you want to remove more than one IP address, submit one DisassociateResolverEndpointIpAddress request for each IP address. To add an IP address to an endpoint, see AssociateResolverEndpointIpAddress.

    Args:
        resolver_endpoint_id(str): The ID of the Resolver endpoint that you want to disassociate an IP address from.
        ip_address(Dict): The IPv4 address that you want to remove from a Resolver endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.ip_address.disassociate(
                ctx, resolver_endpoint_id=value, ip_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.ip_address.disassociate resolver_endpoint_id=value, ip_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="disassociate_resolver_endpoint_ip_address",
        op_kwargs={"ResolverEndpointId": resolver_endpoint_id, "IpAddress": ip_address},
    )


async def list_all(
    hub, ctx, resolver_endpoint_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the IP addresses for a specified Resolver endpoint.

    Args:
        resolver_endpoint_id(str): The ID of the Resolver endpoint that you want to get IP addresses for.
        max_results(int, optional): The maximum number of IP addresses that you want to return in the response to a ListResolverEndpointIpAddresses request. If you don't specify a value for MaxResults, Resolver returns up to 100 IP addresses. . Defaults to None.
        next_token(str, optional): For the first ListResolverEndpointIpAddresses request, omit this value. If the specified Resolver endpoint has more than MaxResults IP addresses, you can submit another ListResolverEndpointIpAddresses request to get the next group of IP addresses. In the next request, specify the value of NextToken from the previous response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.ip_address.list_all(
                ctx, resolver_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.ip_address.list_all resolver_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_endpoint_ip_addresses",
        op_kwargs={
            "ResolverEndpointId": resolver_endpoint_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    time_period: Dict,
    granularity: str,
    metrics: List,
    filter_: Dict = None,
    group_by: List = None,
    next_page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves cost and usage metrics for your account. You can specify which cost and usage-related metric, such as BlendedCosts or UsageQuantity, that you want the request to return. You can also filter and group your data by various dimensions, such as SERVICE or AZ, in a specific time range. For a complete list of valid dimensions, see the GetDimensionValues operation. Management account in an organization in AWS Organizations have access to all member accounts. For information about filter limitations, see Quotas and restrictions in the Billing and Cost Management User Guide.

    Args:
        time_period(Dict): Sets the start and end dates for retrieving AWS costs. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01.
        granularity(str): Sets the AWS cost granularity to MONTHLY or DAILY, or HOURLY. If Granularity isn't set, the response object doesn't include the Granularity, either MONTHLY or DAILY, or HOURLY. .
        filter_(Dict, optional): Filters AWS costs by different dimensions. For example, you can specify SERVICE and LINKED_ACCOUNT and get the costs that are associated with that account's usage of that service. You can nest Expression objects to define any combination of dimension filters. For more information, see Expression. . Defaults to None.
        metrics(List): Which metrics are returned in the query. For more information about blended and unblended rates, see Why does the "blended" annotation appear on some line items in my bill?.  Valid values are AmortizedCost, BlendedCost, NetAmortizedCost, NetUnblendedCost, NormalizedUsageAmount, UnblendedCost, and UsageQuantity.   If you return the UsageQuantity metric, the service aggregates all usage numbers without taking into account the units. For example, if you aggregate usageQuantity across all of Amazon EC2, the results aren't meaningful because Amazon EC2 compute hours and data transfer are measured in different units (for example, hours vs. GB). To get more meaningful UsageQuantity metrics, filter by UsageType or UsageTypeGroups.    Metrics is required for GetCostAndUsage requests.
        group_by(List, optional): You can group AWS costs using up to two different groups, either dimensions, tag keys, cost categories, or any two group by types. When you group by tag key, you get all tag values, including empty strings. Valid values are AZ, INSTANCE_TYPE, LEGAL_ENTITY_NAME, LINKED_ACCOUNT, OPERATION, PLATFORM, PURCHASE_TYPE, SERVICE, TAGS, TENANCY, RECORD_TYPE, and USAGE_TYPE. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.and_usage.init.get(
                ctx, time_period=value, granularity=value, metrics=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.and_usage.init.get time_period=value, granularity=value, metrics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_cost_and_usage",
        op_kwargs={
            "TimePeriod": time_period,
            "Granularity": granularity,
            "Filter": filter_,
            "Metrics": metrics,
            "GroupBy": group_by,
            "NextPageToken": next_page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, project_name: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty Amazon Lookout for Vision project. After you create the project, add a dataset by calling CreateDataset. This operation requires permissions to perform the lookoutvision:CreateProject operation.

    Args:
        project_name(str): The name for the project.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to CreateProject completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from CreateProject. In this case, safely retry your call to CreateProject by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to CreateProject. An idempotency token is active for 8 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.project.create(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.project.create project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="create_project",
        op_kwargs={"ProjectName": project_name, "ClientToken": client_token},
    )


async def delete(hub, ctx, project_name: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon Lookout for Vision project. To delete a project, you must first delete each version of the model associated with the project. To delete a model use the DeleteModel operation. You also have to delete the dataset(s) associated with the model. For more information, see DeleteDataset. The images referenced by the training and test datasets aren't deleted.  This operation requires permissions to perform the lookoutvision:DeleteProject operation.

    Args:
        project_name(str): The name of the project to delete.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to DeleteProject completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from DeleteProject. In this case, safely retry your call to DeleteProject by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to DeleteProject. An idempotency token is active for 8 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.project.delete(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.project.delete project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="delete_project",
        op_kwargs={"ProjectName": project_name, "ClientToken": client_token},
    )


async def describe(hub, ctx, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an Amazon Lookout for Vision project. This operation requires permissions to perform the lookoutvision:DescribeProject operation.

    Args:
        project_name(str): The name of the project that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.project.describe(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.project.describe project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="describe_project",
        op_kwargs={"ProjectName": project_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon Lookout for Vision projects in your AWS account. This operation requires permissions to perform the lookoutvision:ListProjects operation.

    Args:
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Lookout for Vision returns a pagination token in the response. You can use this pagination token to retrieve the next set of projects. Defaults to None.
        max_results(int, optional): The maximum number of results to return per paginated call. The largest value you can specify is 100. If you specify a value greater than 100, a ValidationException error occurs. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="list_projects",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, caller_reference: str, health_check_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new health check. For information about adding health checks to resource record sets, see HealthCheckId in ChangeResourceRecordSets.   ELB Load Balancers  If you're registering EC2 instances with an Elastic Load Balancing (ELB) load balancer, do not create Amazon Route 53 health checks for the EC2 instances. When you register an EC2 instance with a load balancer, you configure settings for an ELB health check, which performs a similar function to a Route 53 health check.  Private Hosted Zones  You can associate health checks with failover resource record sets in a private hosted zone. Note the following:   Route 53 health checkers are outside the VPC. To check the health of an endpoint within a VPC by IP address, you must assign a public IP address to the instance in the VPC.   You can configure a health checker to check the health of an external resource that the instance relies on, such as a database server.   You can create a CloudWatch metric, associate an alarm with the metric, and then create a health check that is based on the state of the alarm. For example, you might create a CloudWatch metric that checks the status of the Amazon EC2 StatusCheckFailed metric, add an alarm to the metric, and then create a health check that is based on the state of the alarm. For information about creating CloudWatch metrics and alarms by using the CloudWatch console, see the Amazon CloudWatch User Guide.

    Args:
        caller_reference(str): A unique string that identifies the request and that allows you to retry a failed CreateHealthCheck request without the risk of creating two identical health checks:   If you send a CreateHealthCheck request with the same CallerReference and settings as a previous request, and if the health check doesn't exist, Amazon Route 53 creates the health check. If the health check does exist, Route 53 returns the settings for the existing health check.   If you send a CreateHealthCheck request with the same CallerReference as a deleted health check, regardless of the settings, Route 53 returns a HealthCheckAlreadyExists error.   If you send a CreateHealthCheck request with the same CallerReference as an existing health check but with different settings, Route 53 returns a HealthCheckAlreadyExists error.   If you send a CreateHealthCheck request with a unique CallerReference but settings identical to an existing health check, Route 53 creates the health check.  .
        health_check_config(Dict): A complex type that contains settings for a new health check.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.init.create(
                ctx, caller_reference=value, health_check_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.init.create caller_reference=value, health_check_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_health_check",
        op_kwargs={
            "CallerReference": caller_reference,
            "HealthCheckConfig": health_check_config,
        },
    )


async def delete(hub, ctx, health_check_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a health check.  Amazon Route 53 does not prevent you from deleting a health check even if the health check is associated with one or more resource record sets. If you delete a health check and you don't update the associated resource record sets, the future status of the health check can't be predicted and may change. This will affect the routing of DNS queries for your DNS failover configuration. For more information, see Replacing and Deleting Health Checks in the Amazon Route 53 Developer Guide.  If you're using Cloud Map and you configured Cloud Map to create a Route 53 health check when you register an instance, you can't use the Route 53 DeleteHealthCheck command to delete the health check. The health check is deleted automatically when you deregister the instance; there can be a delay of several hours before the health check is deleted from Route 53.

    Args:
        health_check_id(str): The ID of the health check that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.init.delete(ctx, health_check_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.init.delete health_check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_health_check",
        op_kwargs={"HealthCheckId": health_check_id},
    )


async def get(hub, ctx, health_check_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified health check.

    Args:
        health_check_id(str): The identifier that Amazon Route 53 assigned to the health check when you created it. When you add or update a resource record set, you use this value to specify which health check to use. The value can be up to 64 characters long.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.init.get(ctx, health_check_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.init.get health_check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_health_check",
        op_kwargs={"HealthCheckId": health_check_id},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a list of the health checks that are associated with the current account.

    Args:
        marker(str, optional): If the value of IsTruncated in the previous response was true, you have more health checks. To get another group, submit another ListHealthChecks request.  For the value of marker, specify the value of NextMarker from the previous response, which is the ID of the first health check that Amazon Route 53 will return if you submit another request. If the value of IsTruncated in the previous response was false, there are no more health checks to get. Defaults to None.
        max_items(str, optional): The maximum number of health checks that you want ListHealthChecks to return in response to the current request. Amazon Route 53 returns a maximum of 100 items. If you set MaxItems to a value greater than 100, Route 53 returns only the first 100 health checks. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_health_checks",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub,
    ctx,
    health_check_id: str,
    health_check_version: int = None,
    ip_address: str = None,
    port: int = None,
    resource_path: str = None,
    fully_qualified_domain_name: str = None,
    search_string: str = None,
    failure_threshold: int = None,
    inverted: bool = None,
    disabled: bool = None,
    health_threshold: int = None,
    child_health_checks: List = None,
    enable_sni: bool = None,
    regions: List = None,
    alarm_identifier: Dict = None,
    insufficient_data_health_status: str = None,
    reset_elements: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing health check. Note that some values can't be updated.  For more information about updating health checks, see Creating, Updating, and Deleting Health Checks in the Amazon Route 53 Developer Guide.

    Args:
        health_check_id(str): The ID for the health check for which you want detailed information. When you created the health check, CreateHealthCheck returned the ID in the response, in the HealthCheckId element.
        health_check_version(int, optional): A sequential counter that Amazon Route 53 sets to 1 when you create a health check and increments by 1 each time you update settings for the health check. We recommend that you use GetHealthCheck or ListHealthChecks to get the current value of HealthCheckVersion for the health check that you want to update, and that you include that value in your UpdateHealthCheck request. This prevents Route 53 from overwriting an intervening update:   If the value in the UpdateHealthCheck request matches the value of HealthCheckVersion in the health check, Route 53 updates the health check with the new settings.   If the value of HealthCheckVersion in the health check is greater, the health check was changed after you got the version number. Route 53 does not update the health check, and it returns a HealthCheckVersionMismatch error.  . Defaults to None.
        ip_address(str, optional): The IPv4 or IPv6 IP address for the endpoint that you want Amazon Route 53 to perform health checks on. If you don't specify a value for IPAddress, Route 53 sends a DNS request to resolve the domain name that you specify in FullyQualifiedDomainName at the interval that you specify in RequestInterval. Using an IP address that is returned by DNS, Route 53 then checks the health of the endpoint. Use one of the following formats for the value of IPAddress:     IPv4 address: four values between 0 and 255, separated by periods (.), for example, 192.0.2.44.    IPv6 address: eight groups of four hexadecimal values, separated by colons (:), for example, 2001:0db8:85a3:0000:0000:abcd:0001:2345. You can also shorten IPv6 addresses as described in RFC 5952, for example, 2001:db8:85a3::abcd:1:2345.   If the endpoint is an EC2 instance, we recommend that you create an Elastic IP address, associate it with your EC2 instance, and specify the Elastic IP address for IPAddress. This ensures that the IP address of your instance never changes. For more information, see the applicable documentation:   Linux: Elastic IP Addresses (EIP) in the Amazon EC2 User Guide for Linux Instances    Windows: Elastic IP Addresses (EIP) in the Amazon EC2 User Guide for Windows Instances     If a health check already has a value for IPAddress, you can change the value. However, you can't update an existing health check to add or remove the value of IPAddress.   For more information, see FullyQualifiedDomainName.  Constraints: Route 53 can't check the health of endpoints for which the IP address is in local, private, non-routable, or multicast ranges. For more information about IP addresses for which you can't create health checks, see the following documents:    RFC 5735, Special Use IPv4 Addresses     RFC 6598, IANA-Reserved IPv4 Prefix for Shared Address Space     RFC 5156, Special-Use IPv6 Addresses   . Defaults to None.
        port(int, optional): The port on the endpoint that you want Amazon Route 53 to perform health checks on.  Don't specify a value for Port when you specify a value for Type of CLOUDWATCH_METRIC or CALCULATED. . Defaults to None.
        resource_path(str, optional): The path that you want Amazon Route 53 to request when performing health checks. The path can be any value for which your endpoint will return an HTTP status code of 2xx or 3xx when the endpoint is healthy, for example the file /docs/route53-health-check.html. You can also include query string parameters, for example, /welcome.html?language=jp&login=y.  Specify this value only if you want to change it. Defaults to None.
        fully_qualified_domain_name(str, optional): Amazon Route 53 behavior depends on whether you specify a value for IPAddress.  If a health check already has a value for IPAddress, you can change the value. However, you can't update an existing health check to add or remove the value of IPAddress.    If you specify a value for IPAddress: Route 53 sends health check requests to the specified IPv4 or IPv6 address and passes the value of FullyQualifiedDomainName in the Host header for all health checks except TCP health checks. This is typically the fully qualified DNS name of the endpoint on which you want Route 53 to perform health checks. When Route 53 checks the health of an endpoint, here is how it constructs the Host header:   If you specify a value of 80 for Port and HTTP or HTTP_STR_MATCH for Type, Route 53 passes the value of FullyQualifiedDomainName to the endpoint in the Host header.   If you specify a value of 443 for Port and HTTPS or HTTPS_STR_MATCH for Type, Route 53 passes the value of FullyQualifiedDomainName to the endpoint in the Host header.   If you specify another value for Port and any value except TCP for Type, Route 53 passes  FullyQualifiedDomainName:Port  to the endpoint in the Host header.   If you don't specify a value for FullyQualifiedDomainName, Route 53 substitutes the value of IPAddress in the Host header in each of the above cases.  If you don't specify a value for IPAddress: If you don't specify a value for IPAddress, Route 53 sends a DNS request to the domain that you specify in FullyQualifiedDomainName at the interval you specify in RequestInterval. Using an IPv4 address that is returned by DNS, Route 53 then checks the health of the endpoint.  If you don't specify a value for IPAddress, Route 53 uses only IPv4 to send health checks to the endpoint. If there's no resource record set with a type of A for the name that you specify for FullyQualifiedDomainName, the health check fails with a "DNS resolution failed" error.  If you want to check the health of weighted, latency, or failover resource record sets and you choose to specify the endpoint only by FullyQualifiedDomainName, we recommend that you create a separate health check for each endpoint. For example, create a health check for each HTTP server that is serving content for www.example.com. For the value of FullyQualifiedDomainName, specify the domain name of the server (such as us-east-2-www.example.com), not the name of the resource record sets (www.example.com).  In this configuration, if the value of FullyQualifiedDomainName matches the name of the resource record sets and you then associate the health check with those resource record sets, health check results will be unpredictable.  In addition, if the value of Type is HTTP, HTTPS, HTTP_STR_MATCH, or HTTPS_STR_MATCH, Route 53 passes the value of FullyQualifiedDomainName in the Host header, as it does when you specify a value for IPAddress. If the value of Type is TCP, Route 53 doesn't pass a Host header. Defaults to None.
        search_string(str, optional): If the value of Type is HTTP_STR_MATCH or HTTPS_STR_MATCH, the string that you want Amazon Route 53 to search for in the response body from the specified resource. If the string appears in the response body, Route 53 considers the resource healthy. (You can't change the value of Type when you update a health check.). Defaults to None.
        failure_threshold(int, optional): The number of consecutive health checks that an endpoint must pass or fail for Amazon Route 53 to change the current status of the endpoint from unhealthy to healthy or vice versa. For more information, see How Amazon Route 53 Determines Whether an Endpoint Is Healthy in the Amazon Route 53 Developer Guide. If you don't specify a value for FailureThreshold, the default value is three health checks. Defaults to None.
        inverted(bool, optional): Specify whether you want Amazon Route 53 to invert the status of a health check, for example, to consider a health check unhealthy when it otherwise would be considered healthy. Defaults to None.
        disabled(bool, optional): Stops Route 53 from performing health checks. When you disable a health check, here's what happens:    Health checks that check the health of endpoints: Route 53 stops submitting requests to your application, server, or other resource.    Calculated health checks: Route 53 stops aggregating the status of the referenced health checks.    Health checks that monitor CloudWatch alarms: Route 53 stops monitoring the corresponding CloudWatch metrics.   After you disable a health check, Route 53 considers the status of the health check to always be healthy. If you configured DNS failover, Route 53 continues to route traffic to the corresponding resources. If you want to stop routing traffic to a resource, change the value of Inverted.  Charges for a health check still apply when the health check is disabled. For more information, see Amazon Route 53 Pricing. Defaults to None.
        health_threshold(int, optional): The number of child health checks that are associated with a CALCULATED health that Amazon Route 53 must consider healthy for the CALCULATED health check to be considered healthy. To specify the child health checks that you want to associate with a CALCULATED health check, use the ChildHealthChecks and ChildHealthCheck elements. Note the following:   If you specify a number greater than the number of child health checks, Route 53 always considers this health check to be unhealthy.   If you specify 0, Route 53 always considers this health check to be healthy.  . Defaults to None.
        child_health_checks(List, optional): A complex type that contains one ChildHealthCheck element for each health check that you want to associate with a CALCULATED health check. Defaults to None.
        enable_sni(bool, optional): Specify whether you want Amazon Route 53 to send the value of FullyQualifiedDomainName to the endpoint in the client_hello message during TLS negotiation. This allows the endpoint to respond to HTTPS health check requests with the applicable SSL/TLS certificate. Some endpoints require that HTTPS requests include the host name in the client_hello message. If you don't enable SNI, the status of the health check will be SSL alert handshake_failure. A health check can also have that status for other reasons. If SNI is enabled and you're still getting the error, check the SSL/TLS configuration on your endpoint and confirm that your certificate is valid. The SSL/TLS certificate on your endpoint includes a domain name in the Common Name field and possibly several more in the Subject Alternative Names field. One of the domain names in the certificate should match the value that you specify for FullyQualifiedDomainName. If the endpoint responds to the client_hello message with a certificate that does not include the domain name that you specified in FullyQualifiedDomainName, a health checker will retry the handshake. In the second attempt, the health checker will omit FullyQualifiedDomainName from the client_hello message. Defaults to None.
        regions(List, optional): A complex type that contains one Region element for each region that you want Amazon Route 53 health checkers to check the specified endpoint from. Defaults to None.
        alarm_identifier(Dict, optional): A complex type that identifies the CloudWatch alarm that you want Amazon Route 53 health checkers to use to determine whether the specified health check is healthy. Defaults to None.
        insufficient_data_health_status(str, optional): When CloudWatch has insufficient data about the metric to determine the alarm state, the status that you want Amazon Route 53 to assign to the health check:    Healthy: Route 53 considers the health check to be healthy.    Unhealthy: Route 53 considers the health check to be unhealthy.    LastKnownStatus: Route 53 uses the status of the health check from the last time CloudWatch had sufficient data to determine the alarm state. For new health checks that have no last known status, the default status for the health check is healthy.  . Defaults to None.
        reset_elements(List, optional): A complex type that contains one ResettableElementName element for each element that you want to reset to the default value. Valid values for ResettableElementName include the following:    ChildHealthChecks: Amazon Route 53 resets ChildHealthChecks to null.    FullyQualifiedDomainName: Route 53 resets FullyQualifiedDomainName. to null.    Regions: Route 53 resets the Regions list to the default set of regions.     ResourcePath: Route 53 resets ResourcePath to null.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.init.update(ctx, health_check_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.init.update health_check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="update_health_check",
        op_kwargs={
            "HealthCheckId": health_check_id,
            "HealthCheckVersion": health_check_version,
            "IPAddress": ip_address,
            "Port": port,
            "ResourcePath": resource_path,
            "FullyQualifiedDomainName": fully_qualified_domain_name,
            "SearchString": search_string,
            "FailureThreshold": failure_threshold,
            "Inverted": inverted,
            "Disabled": disabled,
            "HealthThreshold": health_threshold,
            "ChildHealthChecks": child_health_checks,
            "EnableSNI": enable_sni,
            "Regions": regions,
            "AlarmIdentifier": alarm_identifier,
            "InsufficientDataHealthStatus": insufficient_data_health_status,
            "ResetElements": reset_elements,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, instance_snapshot_name: str, instance_name: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a specific virtual private server, or instance. You can use a snapshot to create a new instance that is based on that snapshot. The create instance snapshot operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_snapshot_name(str): The name for your new snapshot.
        instance_name(str): The Lightsail instance on which to base your snapshot.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.snapshot.create(
                ctx, instance_snapshot_name=value, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.snapshot.create instance_snapshot_name=value, instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_instance_snapshot",
        op_kwargs={
            "instanceSnapshotName": instance_snapshot_name,
            "instanceName": instance_name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, instance_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific snapshot of a virtual private server (or instance). The delete instance snapshot operation supports tag-based access control via resource tags applied to the resource identified by instance snapshot name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_snapshot_name(str): The name of the snapshot to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.snapshot.delete(
                ctx, instance_snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.snapshot.delete instance_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_instance_snapshot",
        op_kwargs={"instanceSnapshotName": instance_snapshot_name},
    )


async def get(hub, ctx, instance_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific instance snapshot.

    Args:
        instance_snapshot_name(str): The name of the snapshot for which you are requesting information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.snapshot.get(
                ctx, instance_snapshot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.snapshot.get instance_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instance_snapshot",
        op_kwargs={"instanceSnapshotName": instance_snapshot_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns all instance snapshots for the user's account.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetInstanceSnapshots request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.snapshot.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.snapshot.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instance_snapshots",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, health_check_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the reason that a specified health check failed most recently.

    Args:
        health_check_id(str): The ID for the health check for which you want the last failure reason. When you created the health check, CreateHealthCheck returned the ID in the response, in the HealthCheckId element.  If you want to get the last failure reason for a calculated health check, you must use the Amazon Route 53 console or the CloudWatch console. You can't use GetHealthCheckLastFailureReason for a calculated health check. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.last_failure_reason.get(
                ctx, health_check_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.last_failure_reason.get health_check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_health_check_last_failure_reason",
        op_kwargs={"HealthCheckId": health_check_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific code signing job. You specify the job by using the jobId value that is returned by the StartSigningJob operation.

    Args:
        job_id(str): The ID of the signing job on input.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="describe_signing_job",
        op_kwargs={"jobId": job_id},
    )


async def list_all(
    hub,
    ctx,
    status: str = None,
    platform_id: str = None,
    requested_by: str = None,
    max_results: int = None,
    next_token: str = None,
    is_revoked: bool = None,
    signature_expires_before: str = None,
    signature_expires_after: str = None,
    job_invoker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all your signing jobs. You can use the maxResults parameter to limit the number of signing jobs that are returned in the response. If additional jobs remain to be listed, code signing returns a nextToken value. Use this value in subsequent calls to ListSigningJobs to fetch the remaining values. You can continue calling ListSigningJobs with your maxResults parameter and with new values that code signing returns in the nextToken parameter until all of your signing jobs have been returned.

    Args:
        status(str, optional): A status value with which to filter your results. Defaults to None.
        platform_id(str, optional): The ID of microcontroller platform that you specified for the distribution of your code image. Defaults to None.
        requested_by(str, optional): The IAM principal that requested the signing job. Defaults to None.
        max_results(int, optional): Specifies the maximum number of items to return in the response. Use this parameter when paginating results. If additional items exist beyond the number you specify, the nextToken element is set in the response. Use the nextToken value in a subsequent request to retrieve additional items. . Defaults to None.
        next_token(str, optional): String for specifying the next set of paginated results to return. After you receive a response with truncated results, use this parameter in a subsequent request. Set it to the value of nextToken from the response that you just received. Defaults to None.
        is_revoked(bool, optional): Filters results to return only signing jobs with revoked signatures. Defaults to None.
        signature_expires_before(str, optional): Filters results to return only signing jobs with signatures expiring before a specified timestamp. Defaults to None.
        signature_expires_after(str, optional): Filters results to return only signing jobs with signatures expiring after a specified timestamp. Defaults to None.
        job_invoker(str, optional): Filters results to return only signing jobs initiated by a specified IAM entity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="list_signing_jobs",
        op_kwargs={
            "status": status,
            "platformId": platform_id,
            "requestedBy": requested_by,
            "maxResults": max_results,
            "nextToken": next_token,
            "isRevoked": is_revoked,
            "signatureExpiresBefore": signature_expires_before,
            "signatureExpiresAfter": signature_expires_after,
            "jobInvoker": job_invoker,
        },
    )


async def start(
    hub,
    ctx,
    source: Dict,
    destination: Dict,
    profile_name: str,
    client_request_token: str,
    profile_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a signing job to be performed on the code provided. Signing jobs are viewable by the ListSigningJobs operation for two years after they are performed. Note the following requirements:     You must create an Amazon S3 source bucket. For more information, see Create a Bucket in the Amazon S3 Getting Started Guide.    Your S3 source bucket must be version enabled.   You must create an S3 destination bucket. Code signing uses your S3 destination bucket to write your signed code.   You specify the name of the source and destination buckets when calling the StartSigningJob operation.   You must also specify a request token that identifies your request to code signing.   You can call the DescribeSigningJob and the ListSigningJobs actions after you call StartSigningJob. For a Java example that shows how to use this action, see http://docs.aws.amazon.com/acm/latest/userguide/

    Args:
        source(Dict): The S3 bucket that contains the object to sign or a BLOB that contains your raw code.
        destination(Dict): The S3 bucket in which to save your signed object. The destination contains the name of your bucket and an optional prefix.
        profile_name(str): The name of the signing profile.
        client_request_token(str): String that identifies the signing request. All calls after the first that use this token return the same response as the first call.
        profile_owner(str, optional): The AWS account ID of the signing profile owner. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.signing.job.start(
                ctx, source=value, destination=value, profile_name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.signing.job.start source=value, destination=value, profile_name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="start_signing_job",
        op_kwargs={
            "source": source,
            "destination": destination,
            "profileName": profile_name,
            "clientRequestToken": client_request_token,
            "profileOwner": profile_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    id_: str,
    packaging_group_id: str,
    source_arn: str,
    source_role_arn: str,
    resource_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new MediaPackage VOD Asset resource.

    Args:
        id_(str): The unique identifier for the Asset.
        packaging_group_id(str): The ID of the PackagingGroup for the Asset.
        resource_id(str, optional): The resource ID to include in SPEKE key requests. Defaults to None.
        source_arn(str): ARN of the source object in S3.
        source_role_arn(str): The IAM role ARN used to access the source S3 bucket.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.asset.create(
                ctx, id_=value, packaging_group_id=value, source_arn=value, source_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.asset.create id_=value, packaging_group_id=value, source_arn=value, source_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="create_asset",
        op_kwargs={
            "Id": id_,
            "PackagingGroupId": packaging_group_id,
            "ResourceId": resource_id,
            "SourceArn": source_arn,
            "SourceRoleArn": source_role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing MediaPackage VOD Asset resource.

    Args:
        id_(str): The ID of the MediaPackage VOD Asset resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.asset.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.asset.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="delete_asset",
        op_kwargs={"Id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of a MediaPackage VOD Asset resource.

    Args:
        id_(str): The ID of an MediaPackage VOD Asset resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.asset.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.asset.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="describe_asset",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    packaging_group_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of MediaPackage VOD Asset resources.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.
        packaging_group_id(str, optional): Returns Assets associated with the specified PackagingGroup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.asset.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.asset.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="list_assets",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "PackagingGroupId": packaging_group_id,
        },
    )
